pub struct CommitValidator { /* private fields */ }Expand description
Implementations
Sourceimpl CommitValidator
impl CommitValidator
Sourcepub fn new(pool: SqlitePool) -> Self
pub fn new(pool: SqlitePool) -> Self
Creates a new validator backed by the given SQLite pool (source branch).
Sourcepub async fn from_branch(branch: &Branch) -> BranchResult<Self>
pub async fn from_branch(branch: &Branch) -> BranchResult<Self>
Opens a validator from a branch db_path.
Sourcepub async fn validate(
&self,
cherry: &CherryPick,
source: &Branch,
target: &Branch,
) -> BranchResult<ValidationReport>
pub async fn validate( &self, cherry: &CherryPick, source: &Branch, target: &Branch, ) -> BranchResult<ValidationReport>
Validates the cherry-pick against the source and target branches.
Checks performed:
- Source branch must be
ActiveorDormant - Target branch must be
Active - All specified entity ids must exist in the source database
- No obvious foreign-key invariant violations in the target